package
Version:
v0.0.0-...-5e46497
Opens a new window with list of versions in this module.
Published: May 2, 2023
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
DB is a global variable that represents the database connection
InitDB initializes the database connection
type Config struct {
DSN string `mapstructure:"DSN"`
API_URL string `mapstructure:"API_URL"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.